=======
Credits
=======

Development Lead
----------------

* Chris Dohmen <chris.dohmen11@gmail.com>

Maintainers
-----------

* Chris Dohmen <chris.dohmen11@gmail.com>
* tpural

Contributors
------------

See the `GitHub contributors graph <https://github.com/Expl0dingBanana/aioafero/graphs/contributors>`_.
